Date: 2014-05-14 13:12:00

## Nanotubes

Although NanoCap was designed to produce fullerenes and cap nanotubes, isolated nanotubes can be constructed. These can be either finite in length or periodic along the axial direction.

A nanotube is constructed via:

File–>New Structure–>Single Structure

them click Nanotube from the popup menu.

### 1 Finite tubes

Finite tubes are simply constructed as close to the user defined length as possible. This length is defined in the Calculations–>Input options.

### 2 Periodic tubes

Periodic tubes are constructed using a user defined number of unit cells in the z direction. The number of unit cells can also be found in the Calculations–>Input options.

The nanotube will be associated with a periodic length which can be found in the Information options tab. This will be required by simulation software if the nanotube is to be used in a periodic simulation.